==> kubernetes-model-core-6.0.0-sources.jar: io/fabric8/kubernetes/api/model/PodSecurityContextFluent.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface PodSecurityContextFluent<A extends PodSecurityContextFluent<A>> extends Fluent<A>{
  public Long getFsGroup();
  public A withFsGroup(Long fsGroup);
  public Boolean hasFsGroup();
  public String getFsGroupChangePolicy();
  public A withFsGroupChangePolicy(String fsGroupChangePolicy);
  public Boolean hasFsGroupChangePolicy();
  public Long getRunAsGroup();
  public A withRunAsGroup(Long runAsGroup);
  public Boolean hasRunAsGroup();
  public Boolean getRunAsNonRoot();
  public A withRunAsNonRoot(Boolean runAsNonRoot);
  public Boolean hasRunAsNonRoot();
  public Long getRunAsUser();
  public A withRunAsUser(Long runAsUser);
  public Boolean hasRunAsUser();
  
  /**
   * This method has been deprecated, please use method buildSeLinuxOptions instead.
   * @return The buildable object.
   */
  @Deprecated
  public SELinuxOptions getSeLinuxOptions();
  public SELinuxOptions buildSeLinuxOptions();
  public A withSeLinuxOptions(SELinuxOptions seLinuxOptions);
  public Boolean hasSeLinuxOptions();
  public A withNewSeLinuxOptions(String level,String role,String type,String user);
  public PodSecurityContextFluent.SeLinuxOptionsNested<A> withNewSeLinuxOptions();
  public PodSecurityContextFluent.SeLinuxOptionsNested<A> withNewSeLinuxOptionsLike(SELinuxOptions item);
  public PodSecurityContextFluent.SeLinuxOptionsNested<A> editSeLinuxOptions();
  public PodSecurityContextFluent.SeLinuxOptionsNested<A> editOrNewSeLinuxOptions();
  public PodSecurityContextFluent.SeLinuxOptionsNested<A> editOrNewSeLinuxOptionsLike(SELinuxOptions item);
  
  /**
   * This method has been deprecated, please use method buildSeccompProfile instead.
   * @return The buildable object.
   */
  @Deprecated
  public SeccompProfile getSeccompProfile();
  public SeccompProfile buildSeccompProfile();
  public A withSeccompProfile(SeccompProfile seccompProfile);
  public Boolean hasSeccompProfile();
  public A withNewSeccompProfile(String localhostProfile,String type);
  public PodSecurityContextFluent.SeccompProfileNested<A> withNewSeccompProfile();
  public PodSecurityContextFluent.SeccompProfileNested<A> withNewSeccompProfileLike(SeccompProfile item);
  public PodSecurityContextFluent.SeccompProfileNested<A> editSeccompProfile();
  public PodSecurityContextFluent.SeccompProfileNested<A> editOrNewSeccompProfile();
  public PodSecurityContextFluent.SeccompProfileNested<A> editOrNewSeccompProfileLike(SeccompProfile item);
  public A addToSupplementalGroups(Integer index,Long item);
  public A setToSupplementalGroups(Integer index,Long item);
  public A addToSupplementalGroups(java.lang.Long... items);
  public A addAllToSupplementalGroups(Collection<Long> items);
  public A removeFromSupplementalGroups(java.lang.Long... items);
  public A removeAllFromSupplementalGroups(Collection<Long> items);
  public List<Long> getSupplementalGroups();
  public Long getSupplementalGroup(Integer index);
  public Long getFirstSupplementalGroup();
  public Long getLastSupplementalGroup();
  public Long getMatchingSupplementalGroup(Predicate<Long> predicate);
  public Boolean hasMatchingSupplementalGroup(Predicate<Long> predicate);
  public A withSupplementalGroups(List<Long> supplementalGroups);
  public A withSupplementalGroups(java.lang.Long... supplementalGroups);
  public Boolean hasSupplementalGroups();
  public A addToSysctls(Integer index,Sysctl item);
  public A setToSysctls(Integer index,Sysctl item);
  public A addToSysctls(io.fabric8.kubernetes.api.model.Sysctl... items);
  public A addAllToSysctls(Collection<Sysctl> items);
  public A removeFromSysctls(io.fabric8.kubernetes.api.model.Sysctl... items);
  public A removeAllFromSysctls(Collection<Sysctl> items);
  public A removeMatchingFromSysctls(Predicate<SysctlBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildSysctls instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Sysctl> getSysctls();
  public List<Sysctl> buildSysctls();
  public Sysctl buildSysctl(Integer index);
  public Sysctl buildFirstSysctl();
  public Sysctl buildLastSysctl();
  public Sysctl buildMatchingSysctl(Predicate<SysctlBuilder> predicate);
  public Boolean hasMatchingSysctl(Predicate<SysctlBuilder> predicate);
  public A withSysctls(List<Sysctl> sysctls);
  public A withSysctls(io.fabric8.kubernetes.api.model.Sysctl... sysctls);
  public Boolean hasSysctls();
  public A addNewSysctl(String name,String value);
  public PodSecurityContextFluent.SysctlsNested<A> addNewSysctl();
  public PodSecurityContextFluent.SysctlsNested<A> addNewSysctlLike(Sysctl item);
  public PodSecurityContextFluent.SysctlsNested<A> setNewSysctlLike(Integer index,Sysctl item);
  public PodSecurityContextFluent.SysctlsNested<A> editSysctl(Integer index);
  public PodSecurityContextFluent.SysctlsNested<A> editFirstSysctl();
  public PodSecurityContextFluent.SysctlsNested<A> editLastSysctl();
  public PodSecurityContextFluent.SysctlsNested<A> editMatchingSysctl(Predicate<SysctlBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildWindowsOptions instead.
   * @return The buildable object.
   */
  @Deprecated
  public WindowsSecurityContextOptions getWindowsOptions();
  public WindowsSecurityContextOptions buildWindowsOptions();
  public A withWindowsOptions(WindowsSecurityContextOptions windowsOptions);
  public Boolean hasWindowsOptions();
  public A withNewWindowsOptions(String gmsaCredentialSpec,String gmsaCredentialSpecName,Boolean hostProcess,String runAsUserName);
  public PodSecurityContextFluent.WindowsOptionsNested<A> withNewWindowsOptions();
  public PodSecurityContextFluent.WindowsOptionsNested<A> withNewWindowsOptionsLike(WindowsSecurityContextOptions item);
  public PodSecurityContextFluent.WindowsOptionsNested<A> editWindowsOptions();
  public PodSecurityContextFluent.WindowsOptionsNested<A> editOrNewWindowsOptions();
  public PodSecurityContextFluent.WindowsOptionsNested<A> editOrNewWindowsOptionsLike(WindowsSecurityContextOptions item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public A withRunAsNonRoot();
  public interface SeLinuxOptionsNested<N> extends Nested<N>,SELinuxOptionsFluent<PodSecurityContextFluent.SeLinuxOptionsNested<N>>{
    public N and();
    public N endSeLinuxOptions();
    
  }
  public interface SeccompProfileNested<N> extends Nested<N>,SeccompProfileFluent<PodSecurityContextFluent.SeccompProfileNested<N>>{
    public N and();
    public N endSeccompProfile();
    
  }
  public interface SysctlsNested<N> extends Nested<N>,SysctlFluent<PodSecurityContextFluent.SysctlsNested<N>>{
    public N and();
    public N endSysctl();
    
  }
  public interface WindowsOptionsNested<N> extends Nested<N>,WindowsSecurityContextOptionsFluent<PodSecurityContextFluent.WindowsOptionsNested<N>>{
    public N and();
    public N endWindowsOptions();
    
  }
  
}

==> kubernetes-model-core-6.7.1-sources.jar: io/fabric8/kubernetes/api/model/PodSecurityContextFluent.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface PodSecurityContextFluent<A extends PodSecurityContextFluent<A>> extends Fluent<A>{
  public Long getFsGroup();
  public A withFsGroup(Long fsGroup);
  public Boolean hasFsGroup();
  public String getFsGroupChangePolicy();
  public A withFsGroupChangePolicy(String fsGroupChangePolicy);
  public Boolean hasFsGroupChangePolicy();
  public Long getRunAsGroup();
  public A withRunAsGroup(Long runAsGroup);
  public Boolean hasRunAsGroup();
  public Boolean getRunAsNonRoot();
  public A withRunAsNonRoot(Boolean runAsNonRoot);
  public Boolean hasRunAsNonRoot();
  public Long getRunAsUser();
  public A withRunAsUser(Long runAsUser);
  public Boolean hasRunAsUser();
  
  /**
   * This method has been deprecated, please use method buildSeLinuxOptions instead.
   * @return The buildable object.
   */
  @Deprecated
  public SELinuxOptions getSeLinuxOptions();
  public SELinuxOptions buildSeLinuxOptions();
  public A withSeLinuxOptions(SELinuxOptions seLinuxOptions);
  public Boolean hasSeLinuxOptions();
  public A withNewSeLinuxOptions(String level,String role,String type,String user);
  public PodSecurityContextFluent.SeLinuxOptionsNested<A> withNewSeLinuxOptions();
  public PodSecurityContextFluent.SeLinuxOptionsNested<A> withNewSeLinuxOptionsLike(SELinuxOptions item);
  public PodSecurityContextFluent.SeLinuxOptionsNested<A> editSeLinuxOptions();
  public PodSecurityContextFluent.SeLinuxOptionsNested<A> editOrNewSeLinuxOptions();
  public PodSecurityContextFluent.SeLinuxOptionsNested<A> editOrNewSeLinuxOptionsLike(SELinuxOptions item);
  
  /**
   * This method has been deprecated, please use method buildSeccompProfile instead.
   * @return The buildable object.
   */
  @Deprecated
  public SeccompProfile getSeccompProfile();
  public SeccompProfile buildSeccompProfile();
  public A withSeccompProfile(SeccompProfile seccompProfile);
  public Boolean hasSeccompProfile();
  public A withNewSeccompProfile(String localhostProfile,String type);
  public PodSecurityContextFluent.SeccompProfileNested<A> withNewSeccompProfile();
  public PodSecurityContextFluent.SeccompProfileNested<A> withNewSeccompProfileLike(SeccompProfile item);
  public PodSecurityContextFluent.SeccompProfileNested<A> editSeccompProfile();
  public PodSecurityContextFluent.SeccompProfileNested<A> editOrNewSeccompProfile();
  public PodSecurityContextFluent.SeccompProfileNested<A> editOrNewSeccompProfileLike(SeccompProfile item);
  public A addToSupplementalGroups(int index,Long item);
  public A setToSupplementalGroups(int index,Long item);
  public A addToSupplementalGroups(java.lang.Long... items);
  public A addAllToSupplementalGroups(Collection<Long> items);
  public A removeFromSupplementalGroups(java.lang.Long... items);
  public A removeAllFromSupplementalGroups(Collection<Long> items);
  public List<Long> getSupplementalGroups();
  public Long getSupplementalGroup(int index);
  public Long getFirstSupplementalGroup();
  public Long getLastSupplementalGroup();
  public Long getMatchingSupplementalGroup(Predicate<Long> predicate);
  public Boolean hasMatchingSupplementalGroup(Predicate<Long> predicate);
  public A withSupplementalGroups(List<Long> supplementalGroups);
  public A withSupplementalGroups(java.lang.Long... supplementalGroups);
  public Boolean hasSupplementalGroups();
  public A addToSysctls(int index,Sysctl item);
  public A setToSysctls(int index,Sysctl item);
  public A addToSysctls(io.fabric8.kubernetes.api.model.Sysctl... items);
  public A addAllToSysctls(Collection<Sysctl> items);
  public A removeFromSysctls(io.fabric8.kubernetes.api.model.Sysctl... items);
  public A removeAllFromSysctls(Collection<Sysctl> items);
  public A removeMatchingFromSysctls(Predicate<SysctlBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildSysctls instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<Sysctl> getSysctls();
  public List<Sysctl> buildSysctls();
  public Sysctl buildSysctl(int index);
  public Sysctl buildFirstSysctl();
  public Sysctl buildLastSysctl();
  public Sysctl buildMatchingSysctl(Predicate<SysctlBuilder> predicate);
  public Boolean hasMatchingSysctl(Predicate<SysctlBuilder> predicate);
  public A withSysctls(List<Sysctl> sysctls);
  public A withSysctls(io.fabric8.kubernetes.api.model.Sysctl... sysctls);
  public Boolean hasSysctls();
  public A addNewSysctl(String name,String value);
  public PodSecurityContextFluent.SysctlsNested<A> addNewSysctl();
  public PodSecurityContextFluent.SysctlsNested<A> addNewSysctlLike(Sysctl item);
  public PodSecurityContextFluent.SysctlsNested<A> setNewSysctlLike(int index,Sysctl item);
  public PodSecurityContextFluent.SysctlsNested<A> editSysctl(int index);
  public PodSecurityContextFluent.SysctlsNested<A> editFirstSysctl();
  public PodSecurityContextFluent.SysctlsNested<A> editLastSysctl();
  public PodSecurityContextFluent.SysctlsNested<A> editMatchingSysctl(Predicate<SysctlBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildWindowsOptions instead.
   * @return The buildable object.
   */
  @Deprecated
  public WindowsSecurityContextOptions getWindowsOptions();
  public WindowsSecurityContextOptions buildWindowsOptions();
  public A withWindowsOptions(WindowsSecurityContextOptions windowsOptions);
  public Boolean hasWindowsOptions();
  public A withNewWindowsOptions(String gmsaCredentialSpec,String gmsaCredentialSpecName,Boolean hostProcess,String runAsUserName);
  public PodSecurityContextFluent.WindowsOptionsNested<A> withNewWindowsOptions();
  public PodSecurityContextFluent.WindowsOptionsNested<A> withNewWindowsOptionsLike(WindowsSecurityContextOptions item);
  public PodSecurityContextFluent.WindowsOptionsNested<A> editWindowsOptions();
  public PodSecurityContextFluent.WindowsOptionsNested<A> editOrNewWindowsOptions();
  public PodSecurityContextFluent.WindowsOptionsNested<A> editOrNewWindowsOptionsLike(WindowsSecurityContextOptions item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public A withRunAsNonRoot();
  public interface SeLinuxOptionsNested<N> extends Nested<N>,SELinuxOptionsFluent<PodSecurityContextFluent.SeLinuxOptionsNested<N>>{
    public N and();
    public N endSeLinuxOptions();
    
  }
  public interface SeccompProfileNested<N> extends Nested<N>,SeccompProfileFluent<PodSecurityContextFluent.SeccompProfileNested<N>>{
    public N and();
    public N endSeccompProfile();
    
  }
  public interface SysctlsNested<N> extends Nested<N>,SysctlFluent<PodSecurityContextFluent.SysctlsNested<N>>{
    public N and();
    public N endSysctl();
    
  }
  public interface WindowsOptionsNested<N> extends Nested<N>,WindowsSecurityContextOptionsFluent<PodSecurityContextFluent.WindowsOptionsNested<N>>{
    public N and();
    public N endWindowsOptions();
    
  }
  
}
